@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2003 Matteo Frigo
- * Copyright (c) 2003 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 
 /* guru interface: requires care in alignment, etcetera. */
 void X(execute_r2r)(const X(plan) p, R *in, R *out)
-WITH_ALIGNED_STACK({
+{
      plan_rdft *pln = (plan_rdft *) p->pln;
      pln->apply((plan *) pln, in, out);
-})
+}
