@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2003, 2006 Matteo Frigo
- * Copyright (c) 2003, 2006 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 
 /* guru interface: requires care in alignment, r - i, etcetera. */
 void X(execute_split_dft)(const X(plan) p, R *ri, R *ii, R *ro, R *io)
-WITH_ALIGNED_STACK({
+{
      plan_dft *pln = (plan_dft *) p->pln;
      pln->apply((plan *) pln, ri, ii, ro, io);
-})
+}
