@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2003 Matteo Frigo
- * Copyright (c) 2003 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,28 +23,28 @@
    f77api.c, possibly multiple times in order to support multiple
    compiler manglings (via redefinition of F77). */
 
-void F77(execute, EXECUTE)(X(plan) * const p)
-WITH_ALIGNED_STACK({
+FFTW_VOIDFUNC F77(execute, EXECUTE)(X(plan) * const p)
+{
      plan *pln = (*p)->pln;
      pln->adt->solve(pln, (*p)->prb);
-})
+}
 
-void F77(destroy_plan, DESTROY_PLAN)(X(plan) *p)
+FFTW_VOIDFUNC F77(destroy_plan, DESTROY_PLAN)(X(plan) *p)
 {
      X(destroy_plan)(*p);
 }
 
-void F77(cleanup, CLEANUP)(void)
+FFTW_VOIDFUNC F77(cleanup, CLEANUP)(void)
 {
      X(cleanup)();
 }
 
-void F77(forget_wisdom, FORGET_WISDOM)(void)
+FFTW_VOIDFUNC F77(forget_wisdom, FORGET_WISDOM)(void)
 {
      X(forget_wisdom)();
 }
 
-void F77(export_wisdom, EXPORT_WISDOM)(void (*f77_write_char)(char *, void *),
+FFTW_VOIDFUNC F77(export_wisdom, EXPORT_WISDOM)(void (*f77_write_char)(char *, void *),
 				       void *data)
 {
      write_char_data ad;
@@ -53,7 +53,7 @@ void F77(export_wisdom, EXPORT_WISDOM)(void (*f77_write_char)(char *, void *),
      X(export_wisdom)(write_char, (void *) &ad);
 }
 
-void F77(import_wisdom, IMPORT_WISDOM)(int *isuccess,
+FFTW_VOIDFUNC F77(import_wisdom, IMPORT_WISDOM)(int *isuccess,
 				       void (*f77_read_char)(int *, void *),
 				       void *data)
 {
@@ -63,24 +63,35 @@ void F77(import_wisdom, IMPORT_WISDOM)(int *isuccess,
      *isuccess = X(import_wisdom)(read_char, (void *) &ed);
 }
 
-void F77(import_system_wisdom, IMPORT_SYSTEM_WISDOM)(int *isuccess)
+FFTW_VOIDFUNC F77(import_system_wisdom, IMPORT_SYSTEM_WISDOM)(int *isuccess)
 {
      *isuccess = X(import_system_wisdom)();
 }
 
-void F77(print_plan, PRINT_PLAN)(X(plan) * const p)
+FFTW_VOIDFUNC F77(print_plan, PRINT_PLAN)(X(plan) * const p)
 {
      X(print_plan)(*p);
+     fflush(stdout);
 }
 
-void F77(flops,FLOPS)(X(plan) *p, double *add, double *mul, double *fma)
+FFTW_VOIDFUNC F77(flops,FLOPS)(X(plan) *p, double *add, double *mul, double *fma)
 {
      X(flops)(*p, add, mul, fma);
 }
 
+FFTW_VOIDFUNC F77(estimate_cost,ESTIMATE_COST)(double *cost, X(plan) * const p)
+{
+     *cost = X(estimate_cost)(*p);
+}
+
+FFTW_VOIDFUNC F77(cost,COST)(double *cost, X(plan) * const p)
+{
+     *cost = X(cost)(*p);
+}
+
 /******************************** DFT ***********************************/
 
-void F77(plan_dft, PLAN_DFT)(X(plan) *p, int *rank, const int *n,
+FFTW_VOIDFUNC F77(plan_dft, PLAN_DFT)(X(plan) *p, int *rank, const int *n,
 			     C *in, C *out, int *sign, int *flags)
 {
      int *nrev = reverse_n(*rank, n);
@@ -88,26 +99,26 @@ void F77(plan_dft, PLAN_DFT)(X(plan) *p, int *rank, const int *n,
      X(ifree0)(nrev);
 }
 
-void F77(plan_dft_1d, PLAN_DFT_1D)(X(plan) *p, int *n, C *in, C *out,
+FFTW_VOIDFUNC F77(plan_dft_1d, PLAN_DFT_1D)(X(plan) *p, int *n, C *in, C *out,
 				   int *sign, int *flags)
 {
      *p = X(plan_dft_1d)(*n, in, out, *sign, *flags);
 }
 
-void F77(plan_dft_2d, PLAN_DFT_2D)(X(plan) *p, int *nx, int *ny,
+FFTW_VOIDFUNC F77(plan_dft_2d, PLAN_DFT_2D)(X(plan) *p, int *nx, int *ny,
 				   C *in, C *out, int *sign, int *flags)
 {
      *p = X(plan_dft_2d)(*ny, *nx, in, out, *sign, *flags);
 }
 
-void F77(plan_dft_3d, PLAN_DFT_3D)(X(plan) *p, int *nx, int *ny, int *nz,
+FFTW_VOIDFUNC F77(plan_dft_3d, PLAN_DFT_3D)(X(plan) *p, int *nx, int *ny, int *nz,
 				   C *in, C *out,
 				   int *sign, int *flags)
 {
      *p = X(plan_dft_3d)(*nz, *ny, *nx, in, out, *sign, *flags);
 }
 
-void F77(plan_many_dft, PLAN_MANY_DFT)(X(plan) *p, int *rank, const int *n,
+FFTW_VOIDFUNC F77(plan_many_dft, PLAN_MANY_DFT)(X(plan) *p, int *rank, const int *n,
 				       int *howmany,
 				       C *in, const int *inembed,
 				       int *istride, int *idist,
@@ -127,7 +138,7 @@ void F77(plan_many_dft, PLAN_MANY_DFT)(X(plan) *p, int *rank, const int *n,
      X(ifree0)(nrev);
 }
 
-void F77(plan_guru_dft, PLAN_GURU_DFT)(X(plan) *p, int *rank, const int *n,
+FFTW_VOIDFUNC F77(plan_guru_dft, PLAN_GURU_DFT)(X(plan) *p, int *rank, const int *n,
 				       const int *is, const int *os,
 				       int *howmany_rank, const int *h_n,
 				       const int *h_is, const int *h_os,
@@ -141,7 +152,7 @@ void F77(plan_guru_dft, PLAN_GURU_DFT)(X(plan) *p, int *rank, const int *n,
      X(ifree0)(dims);
 }
 
-void F77(plan_guru_split_dft, PLAN_GURU_SPLIT_DFT)(X(plan) *p, int *rank, const int *n,
+FFTW_VOIDFUNC F77(plan_guru_split_dft, PLAN_GURU_SPLIT_DFT)(X(plan) *p, int *rank, const int *n,
 				       const int *is, const int *os,
 				       int *howmany_rank, const int *h_n,
 				       const int *h_is, const int *h_os,
@@ -155,25 +166,25 @@ void F77(plan_guru_split_dft, PLAN_GURU_SPLIT_DFT)(X(plan) *p, int *rank, const
      X(ifree0)(dims);
 }
 
-void F77(execute_dft, EXECUTE_DFT)(X(plan) * const p, C *in, C *out)
-WITH_ALIGNED_STACK({
+FFTW_VOIDFUNC F77(execute_dft, EXECUTE_DFT)(X(plan) * const p, C *in, C *out)
+{
      plan_dft *pln = (plan_dft *) (*p)->pln;
      if ((*p)->sign == FFT_SIGN)
           pln->apply((plan *) pln, in[0], in[0]+1, out[0], out[0]+1);
      else
           pln->apply((plan *) pln, in[0]+1, in[0], out[0]+1, out[0]);
-})
+}
 
-void F77(execute_split_dft, EXECUTE_SPLIT_DFT)(X(plan) * const p,
+FFTW_VOIDFUNC F77(execute_split_dft, EXECUTE_SPLIT_DFT)(X(plan) * const p,
 					       R *ri, R *ii, R *ro, R *io)
-WITH_ALIGNED_STACK({
+{
      plan_dft *pln = (plan_dft *) (*p)->pln;
      pln->apply((plan *) pln, ri, ii, ro, io);
-})
+}
 
 /****************************** DFT r2c *********************************/
 
-void F77(plan_dft_r2c, PLAN_DFT_R2C)(X(plan) *p, int *rank, const int *n,
+FFTW_VOIDFUNC F77(plan_dft_r2c, PLAN_DFT_R2C)(X(plan) *p, int *rank, const int *n,
 				     R *in, C *out, int *flags)
 {
      int *nrev = reverse_n(*rank, n);
@@ -181,19 +192,19 @@ void F77(plan_dft_r2c, PLAN_DFT_R2C)(X(plan) *p, int *rank, const int *n,
      X(ifree0)(nrev);
 }
 
-void F77(plan_dft_r2c_1d, PLAN_DFT_R2C_1D)(X(plan) *p, int *n, R *in, C *out,
+FFTW_VOIDFUNC F77(plan_dft_r2c_1d, PLAN_DFT_R2C_1D)(X(plan) *p, int *n, R *in, C *out,
 					   int *flags)
 {
      *p = X(plan_dft_r2c_1d)(*n, in, out, *flags);
 }
 
-void F77(plan_dft_r2c_2d, PLAN_DFT_R2C_2D)(X(plan) *p, int *nx, int *ny,
+FFTW_VOIDFUNC F77(plan_dft_r2c_2d, PLAN_DFT_R2C_2D)(X(plan) *p, int *nx, int *ny,
 					   R *in, C *out, int *flags)
 {
      *p = X(plan_dft_r2c_2d)(*ny, *nx, in, out, *flags);
 }
 
-void F77(plan_dft_r2c_3d, PLAN_DFT_R2C_3D)(X(plan) *p,
+FFTW_VOIDFUNC F77(plan_dft_r2c_3d, PLAN_DFT_R2C_3D)(X(plan) *p,
 					   int *nx, int *ny, int *nz,
 					   R *in, C *out,
 					   int *flags)
@@ -201,7 +212,7 @@ void F77(plan_dft_r2c_3d, PLAN_DFT_R2C_3D)(X(plan) *p,
      *p = X(plan_dft_r2c_3d)(*nz, *ny, *nx, in, out, *flags);
 }
 
-void F77(plan_many_dft_r2c, PLAN_MANY_DFT_R2C)(
+FFTW_VOIDFUNC F77(plan_many_dft_r2c, PLAN_MANY_DFT_R2C)(
      X(plan) *p, int *rank, const int *n,
      int *howmany,
      R *in, const int *inembed, int *istride, int *idist,
@@ -220,7 +231,7 @@ void F77(plan_many_dft_r2c, PLAN_MANY_DFT_R2C)(
      X(ifree0)(nrev);
 }
 
-void F77(plan_guru_dft_r2c, PLAN_GURU_DFT_R2C)(
+FFTW_VOIDFUNC F77(plan_guru_dft_r2c, PLAN_GURU_DFT_R2C)(
      X(plan) *p, int *rank, const int *n,
      const int *is, const int *os,
      int *howmany_rank, const int *h_n,
@@ -235,7 +246,7 @@ void F77(plan_guru_dft_r2c, PLAN_GURU_DFT_R2C)(
      X(ifree0)(dims);
 }
 
-void F77(plan_guru_split_dft_r2c, PLAN_GURU_SPLIT_DFT_R2C)(
+FFTW_VOIDFUNC F77(plan_guru_split_dft_r2c, PLAN_GURU_SPLIT_DFT_R2C)(
      X(plan) *p, int *rank, const int *n,
      const int *is, const int *os,
      int *howmany_rank, const int *h_n,
@@ -250,22 +261,24 @@ void F77(plan_guru_split_dft_r2c, PLAN_GURU_SPLIT_DFT_R2C)(
      X(ifree0)(dims);
 }
 
-void F77(execute_dft_r2c, EXECUTE_DFT_R2C)(X(plan) * const p, R *in, C *out)
-WITH_ALIGNED_STACK({
+FFTW_VOIDFUNC F77(execute_dft_r2c, EXECUTE_DFT_R2C)(X(plan) * const p, R *in, C *out)
+{
      plan_rdft2 *pln = (plan_rdft2 *) (*p)->pln;
-     pln->apply((plan *) pln, in, out[0], out[0]+1);
-})
+     problem_rdft2 *prb = (problem_rdft2 *) (*p)->prb;
+     pln->apply((plan *) pln, in, in + (prb->r1 - prb->r0), out[0], out[0]+1);
+}
 
-void F77(execute_split_dft_r2c, EXECUTE_SPLIT_DFT_R2C)(X(plan) * const p,
+FFTW_VOIDFUNC F77(execute_split_dft_r2c, EXECUTE_SPLIT_DFT_R2C)(X(plan) * const p,
 						       R *in, R *ro, R *io)
-WITH_ALIGNED_STACK({
+{
      plan_rdft2 *pln = (plan_rdft2 *) (*p)->pln;
-     pln->apply((plan *) pln, in, ro, io);
-})
+     problem_rdft2 *prb = (problem_rdft2 *) (*p)->prb;
+     pln->apply((plan *) pln, in, in + (prb->r1 - prb->r0), ro, io);
+}
 
 /****************************** DFT c2r *********************************/
 
-void F77(plan_dft_c2r, PLAN_DFT_C2R)(X(plan) *p, int *rank, const int *n,
+FFTW_VOIDFUNC F77(plan_dft_c2r, PLAN_DFT_C2R)(X(plan) *p, int *rank, const int *n,
 				     C *in, R *out, int *flags)
 {
      int *nrev = reverse_n(*rank, n);
@@ -273,19 +286,19 @@ void F77(plan_dft_c2r, PLAN_DFT_C2R)(X(plan) *p, int *rank, const int *n,
      X(ifree0)(nrev);
 }
 
-void F77(plan_dft_c2r_1d, PLAN_DFT_C2R_1D)(X(plan) *p, int *n, C *in, R *out,
+FFTW_VOIDFUNC F77(plan_dft_c2r_1d, PLAN_DFT_C2R_1D)(X(plan) *p, int *n, C *in, R *out,
 					   int *flags)
 {
      *p = X(plan_dft_c2r_1d)(*n, in, out, *flags);
 }
 
-void F77(plan_dft_c2r_2d, PLAN_DFT_C2R_2D)(X(plan) *p, int *nx, int *ny,
+FFTW_VOIDFUNC F77(plan_dft_c2r_2d, PLAN_DFT_C2R_2D)(X(plan) *p, int *nx, int *ny,
 					   C *in, R *out, int *flags)
 {
      *p = X(plan_dft_c2r_2d)(*ny, *nx, in, out, *flags);
 }
 
-void F77(plan_dft_c2r_3d, PLAN_DFT_C2R_3D)(X(plan) *p,
+FFTW_VOIDFUNC F77(plan_dft_c2r_3d, PLAN_DFT_C2R_3D)(X(plan) *p,
 					   int *nx, int *ny, int *nz,
 					   C *in, R *out,
 					   int *flags)
@@ -293,7 +306,7 @@ void F77(plan_dft_c2r_3d, PLAN_DFT_C2R_3D)(X(plan) *p,
      *p = X(plan_dft_c2r_3d)(*nz, *ny, *nx, in, out, *flags);
 }
 
-void F77(plan_many_dft_c2r, PLAN_MANY_DFT_C2R)(
+FFTW_VOIDFUNC F77(plan_many_dft_c2r, PLAN_MANY_DFT_C2R)(
      X(plan) *p, int *rank, const int *n,
      int *howmany,
      C *in, const int *inembed, int *istride, int *idist,
@@ -312,7 +325,7 @@ void F77(plan_many_dft_c2r, PLAN_MANY_DFT_C2R)(
      X(ifree0)(nrev);
 }
 
-void F77(plan_guru_dft_c2r, PLAN_GURU_DFT_C2R)(
+FFTW_VOIDFUNC F77(plan_guru_dft_c2r, PLAN_GURU_DFT_C2R)(
      X(plan) *p, int *rank, const int *n,
      const int *is, const int *os,
      int *howmany_rank, const int *h_n,
@@ -327,7 +340,7 @@ void F77(plan_guru_dft_c2r, PLAN_GURU_DFT_C2R)(
      X(ifree0)(dims);
 }
 
-void F77(plan_guru_split_dft_c2r, PLAN_GURU_SPLIT_DFT_C2R)(
+FFTW_VOIDFUNC F77(plan_guru_split_dft_c2r, PLAN_GURU_SPLIT_DFT_C2R)(
      X(plan) *p, int *rank, const int *n,
      const int *is, const int *os,
      int *howmany_rank, const int *h_n,
@@ -342,22 +355,24 @@ void F77(plan_guru_split_dft_c2r, PLAN_GURU_SPLIT_DFT_C2R)(
      X(ifree0)(dims);
 }
 
-void F77(execute_dft_c2r, EXECUTE_DFT_C2R)(X(plan) * const p, C *in, R *out)
-WITH_ALIGNED_STACK({
+FFTW_VOIDFUNC F77(execute_dft_c2r, EXECUTE_DFT_C2R)(X(plan) * const p, C *in, R *out)
+{
      plan_rdft2 *pln = (plan_rdft2 *) (*p)->pln;
-     pln->apply((plan *) pln, out, in[0], in[0]+1);
-})
+     problem_rdft2 *prb = (problem_rdft2 *) (*p)->prb;
+     pln->apply((plan *) pln, out, out + (prb->r1 - prb->r0), in[0], in[0]+1);
+}
 
-void F77(execute_split_dft_c2r, EXECUTE_SPLIT_DFT_C2R)(X(plan) * const p,
+FFTW_VOIDFUNC F77(execute_split_dft_c2r, EXECUTE_SPLIT_DFT_C2R)(X(plan) * const p,
 					   R *ri, R *ii, R *out)
-WITH_ALIGNED_STACK({
+{
      plan_rdft2 *pln = (plan_rdft2 *) (*p)->pln;
-     pln->apply((plan *) pln, out, ri, ii);
-})
+     problem_rdft2 *prb = (problem_rdft2 *) (*p)->prb;
+     pln->apply((plan *) pln, out, out + (prb->r1 - prb->r0), ri, ii);
+}
 
 /****************************** r2r *********************************/
 
-void F77(plan_r2r, PLAN_R2R)(X(plan) *p, int *rank, const int *n,
+FFTW_VOIDFUNC F77(plan_r2r, PLAN_R2R)(X(plan) *p, int *rank, const int *n,
 			     R *in, R *out,
 			     int *kind, int *flags)
 {
@@ -368,13 +383,13 @@ void F77(plan_r2r, PLAN_R2R)(X(plan) *p, int *rank, const int *n,
      X(ifree0)(nrev);
 }
 
-void F77(plan_r2r_1d, PLAN_R2R_1D)(X(plan) *p, int *n, R *in, R *out,
+FFTW_VOIDFUNC F77(plan_r2r_1d, PLAN_R2R_1D)(X(plan) *p, int *n, R *in, R *out,
 				   int *kind, int *flags)
 {
      *p = X(plan_r2r_1d)(*n, in, out, (X(r2r_kind)) *kind, *flags);
 }
 
-void F77(plan_r2r_2d, PLAN_R2R_2D)(X(plan) *p, int *nx, int *ny,
+FFTW_VOIDFUNC F77(plan_r2r_2d, PLAN_R2R_2D)(X(plan) *p, int *nx, int *ny,
 				   R *in, R *out, 
 				   int *kindx, int *kindy, int *flags)
 {
@@ -382,7 +397,7 @@ void F77(plan_r2r_2d, PLAN_R2R_2D)(X(plan) *p, int *nx, int *ny,
 			 (X(r2r_kind)) *kindy, (X(r2r_kind)) *kindx, *flags);
 }
 
-void F77(plan_r2r_3d, PLAN_R2R_3D)(X(plan) *p,
+FFTW_VOIDFUNC F77(plan_r2r_3d, PLAN_R2R_3D)(X(plan) *p,
 				   int *nx, int *ny, int *nz,
 				   R *in, R *out,
 				   int *kindx, int *kindy, int *kindz,
@@ -393,7 +408,7 @@ void F77(plan_r2r_3d, PLAN_R2R_3D)(X(plan) *p,
 			 (X(r2r_kind)) *kindx, *flags);
 }
 
-void F77(plan_many_r2r, PLAN_MANY_R2R)(
+FFTW_VOIDFUNC F77(plan_many_r2r, PLAN_MANY_R2R)(
      X(plan) *p, int *rank, const int *n,
      int *howmany,
      R *in, const int *inembed, int *istride, int *idist,
@@ -414,7 +429,7 @@ void F77(plan_many_r2r, PLAN_MANY_R2R)(
      X(ifree0)(nrev);
 }
 
-void F77(plan_guru_r2r, PLAN_GURU_R2R)(
+FFTW_VOIDFUNC F77(plan_guru_r2r, PLAN_GURU_R2R)(
      X(plan) *p, int *rank, const int *n,
      const int *is, const int *os,
      int *howmany_rank, const int *h_n,
@@ -431,8 +446,8 @@ void F77(plan_guru_r2r, PLAN_GURU_R2R)(
      X(ifree0)(dims);
 }
 
-void F77(execute_r2r, EXECUTE_R2R)(X(plan) * const p, R *in, R *out)
-WITH_ALIGNED_STACK({
+FFTW_VOIDFUNC F77(execute_r2r, EXECUTE_R2R)(X(plan) * const p, R *in, R *out)
+{
      plan_rdft *pln = (plan_rdft *) (*p)->pln;
      pln->apply((plan *) pln, in, out);
-})
+}
