@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2003 Matteo Frigo
- * Copyright (c) 2003 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +22,22 @@
 
 void X(flops)(const X(plan) p, double *add, double *mul, double *fma)
 {
+     planner *plnr = X(the_planner)();
      opcnt *o = &p->pln->ops;
      *add = o->add; *mul = o->mul; *fma = o->fma;
+     if (plnr->cost_hook) {
+	  *add = plnr->cost_hook(p->prb, *add, COST_SUM);
+	  *mul = plnr->cost_hook(p->prb, *mul, COST_SUM);
+	  *fma = plnr->cost_hook(p->prb, *fma, COST_SUM);
+     }
+}
+
+double X(estimate_cost)(const X(plan) p)
+{
+     return X(iestimate_cost)(X(the_planner)(), p->pln, p->prb);
+}
+
+double X(cost)(const X(plan) p)
+{
+     return p->pln->pcost;
 }
