@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2003 Matteo Frigo
- * Copyright (c) 2003 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,3 +40,10 @@ void X(cleanup)(void)
           plnr = 0;
      }
 }
+
+void X(set_timelimit)(double tlim) 
+{
+     /* PLNR is not necessarily initialized when this function is
+	called, so use X(the_planner)() */
+     X(the_planner)()->timelimit = tlim; 
+}
