@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2003, 2007-8 Matteo Frigo
- * Copyright (c) 2003, 2007-8 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,7 +22,11 @@
 #include "api.h"
 
 const char X(cc)[] = FFTW_CC;
-const char X(codelet_optim)[] = CODELET_OPTIM;
+
+/* fftw <= 3.2.2 had special compiler flags for codelets, which are
+   not used anymore.  We keep this variable around because it is part
+   of the ABI */
+const char X(codelet_optim)[] = "";
 
 const char X(version)[] = PACKAGE "-" PACKAGE_VERSION
 
@@ -30,14 +34,14 @@ const char X(version)[] = PACKAGE "-" PACKAGE_VERSION
    "-fma"
 #endif
 
-#if HAVE_SSE
-   "-sse"
-#endif
-
 #if HAVE_SSE2
    "-sse2"
 #endif
 
+#if HAVE_AVX
+   "-avx"
+#endif
+
 #if HAVE_ALTIVEC
    "-altivec"
 #endif
