@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2003, 2006 Matteo Frigo
- * Copyright (c) 2003, 2006 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,8 +18,7 @@
  *
  */
 
-#include "codelet-dft.h"
-#include "simd.h"
+#include SIMD_HEADER
 
-#define GENUS X(dft_n1bsimd_genus)
+#define GENUS XSIMD(dft_n1bsimd_genus)
 extern const kdft_genus GENUS;
