@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2003, 2006 Matteo Frigo
- * Copyright (c) 2003, 2006 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  *
  */
 
-#include "simd.h"
+#include SIMD_HEADER
 
 #undef LD
 #define LD LDA
@@ -27,8 +27,9 @@
 
 #define VTW VTW3
 #define TWVL TWVL3
+#define LDW(x) LDA(x, 0, 0) /* load twiddle factor */
 
 /* same as t1f otherwise */
-#define GENUS X(dft_t1fsimd_genus)
+#define GENUS XSIMD(dft_t1fsimd_genus)
 extern const ct_genus GENUS;
 
