@@ -1,7 +1,7 @@
 (*
  * Copyright (c) 1997-1999 Massachusetts Institute of Technology
- * Copyright (c) 2003 Matteo Frigo
- * Copyright (c) 2003 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  *)
-(* $Id: annotate.mli,v 1.6 2003/03/15 20:29:42 stevenj Exp $ *)
 
 open Variable
 open Expr
@@ -31,6 +30,7 @@ and aschedule =
   | AInstr of assignment
   | ASeq of (annotated_schedule * annotated_schedule)
 
-val annotate : Schedule.schedule -> annotated_schedule
+val annotate :
+  variable list list -> Schedule.schedule -> annotated_schedule
 
 val dump : (string -> unit) -> annotated_schedule -> unit
