@@ -1,7 +1,7 @@
 (*
  * Copyright (c) 1997-1999 Massachusetts Institute of Technology
- * Copyright (c) 2003 Matteo Frigo
- * Copyright (c) 2003 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  *)
-(* $Id: genutil.ml,v 1.17 2003/03/15 20:29:42 stevenj Exp $ *)
 
 (* utilities common to all generators *)
 open Util
@@ -34,20 +33,20 @@ let unique_v_array_c veclen n =
   array veclen (fun _ ->
     unique_array_c n)
 
-let locative_array_c n rarr iarr loc = 
+let locative_array_c n rarr iarr loc vs = 
   array n (fun i -> 
     let klass = Unique.make () in
     let (rloc, iloc) = loc i in
-    (Variable.make_locative rloc klass rarr i,
-     Variable.make_locative iloc klass iarr i))
+    (Variable.make_locative rloc klass rarr i vs,
+     Variable.make_locative iloc klass iarr i vs))
 
-let locative_v_array_c veclen n rarr iarr loc = 
+let locative_v_array_c veclen n rarr iarr loc vs = 
   array veclen (fun v ->
     array n (fun i -> 
       let klass = Unique.make () in
       let (rloc, iloc) = loc v i in
-      (Variable.make_locative rloc klass (rarr v) i,
-       Variable.make_locative iloc klass (iarr v) i)))
+      (Variable.make_locative rloc klass (rarr v) i vs,
+       Variable.make_locative iloc klass (iarr v) i vs)))
 
 let temporary_array n = 
   array n (fun i -> Variable.make_temporary ())
@@ -202,16 +201,17 @@ let standard_scheduler dag =
   let alist = To_alist.to_assignments optim in
   let _ = dump_alist alist in
   let _ = dump_dag alist in
-  let sched = Schedule.schedule alist in
-  sched
+    if !Magic.precompute_twiddles then
+      Schedule.isolate_precomputations_and_schedule alist 
+    else
+      Schedule.schedule alist 
 
 let standard_optimizer dag =
   let sched = standard_scheduler dag in
-  let annot = Annotate.annotate sched in
+  let annot = Annotate.annotate [] sched in
   let _ = dump_asched annot in
   annot
 
-
 let size = ref None
 let sign = ref (-1)
 
@@ -237,10 +237,13 @@ let declare_register_fcn name =
   if name = "" then
     "void NAME(planner *p)\n"
   else 
-    "void X(codelet_" ^ name ^ ")(planner *p)\n"
+    "void " ^ (choose_simd "X" "XSIMD") ^
+      "(codelet_" ^ name ^ ")(planner *p)\n"
 
 let stringify name = 
-  if name = "" then "STRINGIZE(NAME)" else "\"" ^ name ^ "\""
+  if name = "" then "STRINGIZE(NAME)" else 
+    choose_simd ("\"" ^ name ^ "\"")
+      ("XSIMD_STRING(\"" ^ name ^ "\")")
 
 let parse user_speclist usage =
   Arg.parse
@@ -291,15 +294,9 @@ let stride_to_string s = function
 let cmdline () =
   List.fold_right (fun a b -> a ^ " " ^ b) (Array.to_list Sys.argv) ""
 
-let unparse cvsid tree =
+let unparse tree =
   "/* Generated by: " ^ (cmdline ()) ^ "*/\n\n" ^
   (C.print_cost tree) ^
-  "/*\n" ^
-  " * Generator Id's : \n" ^
-  " * " ^ Algsimp.cvsid ^ "\n" ^
-  " * " ^ Fft.cvsid ^ "\n" ^
-  " * " ^ cvsid ^ "\n" ^
-  " */\n\n" ^
   (if String.length !Magic.inklude > 0 
   then
     (Printf.sprintf "#include \"%s\"\n\n" !Magic.inklude)
@@ -309,7 +306,7 @@ let unparse cvsid tree =
   else
     C.unparse_function tree)
 
-let add_constants ast = 
+let finalize_fcn ast = 
   let mergedecls = function
       C.Block (d1, [C.Block (d2, s)]) -> C.Block (d1 @ d2, s)
     | x -> x
@@ -319,11 +316,12 @@ let add_constants ast =
     else
       C.extract_constants
 	
-  in mergedecls (C.Block (extract_constants ast, [ast]))
+  in mergedecls (C.Block (extract_constants ast, [ast; C.Simd_leavefun]))
 
-let twinstr_to_string x =
+let twinstr_to_string vl x =
   if !Simdmagic.simd_mode then 
-    Twiddle.twinstr_to_simd_string x
+    Twiddle.twinstr_to_simd_string vl x
   else
     Twiddle.twinstr_to_c_string x
 
+let make_volatile_stride x = C.CCall ("MAKE_VOLATILE_STRIDE", x)
