@@ -1,7 +1,7 @@
 (*
  * Copyright (c) 1997-1999 Massachusetts Institute of Technology
- * Copyright (c) 2003 Matteo Frigo
- * Copyright (c) 2003 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  *)
-(* $Id: simd.mli,v 1.7 2003/03/15 20:29:42 stevenj Exp $ *)
 
 val unparse_function : C.c_fcn -> string
 val extract_constants : C.c_ast -> C.c_decl list
@@ -26,5 +25,4 @@ val realtype : string
 val realtypep : string
 val constrealtype : string
 val constrealtypep : string
-val ivs : string ref
-val ovs : string ref
+
