@@ -1,7 +1,7 @@
 (*
  * Copyright (c) 1997-1999 Massachusetts Institute of Technology
- * Copyright (c) 2003 Matteo Frigo
- * Copyright (c) 2003 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +18,14 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  *)
-(* $Id: simdmagic.ml,v 1.7 2003/03/15 20:29:42 stevenj Exp $ *)
 
 (* SIMD magic parameters *)
 let simd_mode = ref false
+let store_multiple = ref 1
 
 open Magic
 
 let speclist = [
   "-simd", set_bool simd_mode, undocumented;
+  "-store-multiple", set_int store_multiple, undocumented;
 ]
