@@ -1,7 +1,7 @@
 (*
  * Copyright (c) 1997-1999 Massachusetts Institute of Technology
- * Copyright (c) 2003 Matteo Frigo
- * Copyright (c) 2003 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  *)
-(* $Id: to_alist.ml,v 1.8 2003/03/15 20:29:42 stevenj Exp $ *)
 
 (*************************************************************
  * Conversion of the dag to an assignment list
@@ -114,14 +113,15 @@ type fma =
   | FMS of expr * expr * expr   (* FMS (a, b, c) => -a + b * c *)
   | FNMS of expr * expr * expr  (* FNMS (a, b, c) => a - b * c *)
 
-let good_for_fma x = 
-  not !Simdmagic.simd_mode ||
-  match x with
-  | (Num _, _) -> true
-  | (_, Num _) -> true
-  | (NaN I, _) -> true
-  | (_, NaN I) -> true
-  | _ -> false
+let good_for_fma (a, b) = 
+  let good = function
+    | NaN I -> true
+    | NaN CONJ -> true
+    | NaN _ -> false
+    | Times(NaN _, _) -> false
+    | Times(_, NaN _) -> false
+    | _ -> true
+  in good a && good b
 
 let build_fma l = 
   if (not !Magic.enable_fma) then NO_FMA
@@ -155,6 +155,8 @@ let rec visitM x =
 	  visitM b >> visitM b >>
 	  visitM c >> visitM c)
     | Times (a, b) -> visitM a >> visitM b
+    | CTimes (a, b) -> visitM a >> visitM b
+    | CTimesJ (a, b) -> visitM a >> visitM b
     | Uminus a -> visitM a)
     x
 
@@ -208,10 +210,20 @@ let rec expr_of_nodeM x =
               mapM expr_of_nodeM a >>= fun a' ->
 		with_temp_maybeM x (Plus a')
 	end
-    | Times (Times ((NaN _ as n), (Load _ as a)), b) ->
-	(* funny special case for SIMD twiddle factors *)
+    | CTimes (Load _ as a, b) when !Magic.generate_bytw ->
         expr_of_nodeM b >>= fun b' ->
-	  with_tempM (Times (Times (n, a), b'))
+          with_tempM (CTimes (a, b'))
+    | CTimes (a, b) ->
+        expr_of_nodeM a >>= fun a' ->
+          expr_of_nodeM b >>= fun b' ->
+            with_tempM (CTimes (a', b'))
+    | CTimesJ (Load _ as a, b) when !Magic.generate_bytw ->
+        expr_of_nodeM b >>= fun b' ->
+          with_tempM (CTimesJ (a, b'))
+    | CTimesJ (a, b) ->
+        expr_of_nodeM a >>= fun a' ->
+          expr_of_nodeM b >>= fun b' ->
+            with_tempM (CTimesJ (a', b'))
     | Times (a, b) ->
         expr_of_nodeM a >>= fun a' ->
           expr_of_nodeM b >>= fun b' ->
