@@ -1,7 +1,7 @@
 (*
  * Copyright (c) 1997-1999 Massachusetts Institute of Technology
- * Copyright (c) 2003 Matteo Frigo
- * Copyright (c) 2003 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,16 +18,15 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  *)
-(* $Id: twiddle.mli,v 1.5 2003/03/15 20:29:42 stevenj Exp $ *)
 
 val speclist : (string * Arg.spec * string) list
 
 type twinstr
 
 val twiddle_policy :
-    unit ->
-    (int -> int -> (int -> Complex.expr) -> (int -> Complex.expr) ->
-      int -> Complex.expr) *(int -> int) * (int -> twinstr list)
+  int -> bool ->
+  (int -> int -> (int -> Complex.expr) -> (int -> Complex.expr) ->
+     int -> Complex.expr) *(int -> int) * (int -> twinstr list)
 
 val twinstr_to_c_string : twinstr list -> string
-val twinstr_to_simd_string : twinstr list -> string
+val twinstr_to_simd_string : string -> twinstr list -> string
