@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2003 Matteo Frigo
- * Copyright (c) 2003 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
  *
  */
 
-/* $Id: assert.c,v 1.6 2003/03/15 20:29:43 stevenj Exp $ */
 #include "ifftw.h"
 #include <stdio.h>
 #include <stdlib.h>
@@ -27,5 +26,9 @@ void X(assertion_failed)(const char *s, int line, const char *file)
 {
      fflush(stdout);
      fprintf(stderr, "fftw: %s:%d: assertion failed: %s\n", file, line, s);
+#ifdef HAVE_ABORT
+     abort();
+#else
      exit(EXIT_FAILURE);
+#endif
 }
