@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2003 Matteo Frigo
- * Copyright (c) 2003 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +18,12 @@
  *
  */
 
-/* $Id: awake.c,v 1.3 2003/03/15 20:29:43 stevenj Exp $ */
 
 #include "ifftw.h"
 
-void X(null_awake)(plan *ego, int awake)
+void X(null_awake)(plan *ego, enum wakefulness wakefulness)
 {
      UNUSED(ego);
-     UNUSED(awake);
+     UNUSED(wakefulness);
      /* do nothing */
 }
