@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2003, 2007-8 Matteo Frigo
- * Copyright (c) 2003, 2007-8 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 #define POW2P(n) (((n) > 0) && (((n) & ((n) - 1)) == 0))
 
 /* TRUE if radix-r is ugly for size n */
-int X(ct_uglyp)(INT min_n, INT n, INT r)
+int X(ct_uglyp)(INT min_n, INT v, INT n, INT r)
 {
-     return (n <= min_n) || (POW2P(n) && (n / r) <= 4);
+     return (n <= min_n) || (POW2P(n) && (v * (n / r)) <= 4);
 }
