@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2003 Matteo Frigo
- * Copyright (c) 2003 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
  *
  */
 
-/* $Id: tensor1.c,v 1.4 2003/03/15 20:29:43 stevenj Exp $ */
 
 #include "ifftw.h"
 
@@ -27,7 +26,7 @@ tensor *X(mktensor_0d)(void)
      return X(mktensor(0));
 }
 
-tensor *X(mktensor_1d)(int n, int is, int os)
+tensor *X(mktensor_1d)(INT n, INT is, INT os)
 {
      tensor *x = X(mktensor)(1);
      x->dims[0].n = n;
