@@ -18,7 +18,6 @@
  *
  */
 
-/* $Id: report.c,v 1.8 2003/04/11 12:45:37 athena Exp $ */
 
 #include "bench.h"
 #include <stdio.h>
@@ -59,8 +58,8 @@ static void mkstat(double *t, int st, struct stats *a)
 	  for (j = 0; j < i - 1; ++j) {
 	       double t0, t1;
 	       if ((t0 = t[j]) > (t1 = t[j + 1])) {
-		    t[j] = t0;
-		    t[j + 1] = t1;
+		    t[j] = t1;
+		    t[j + 1] = t0;
 	       }
 	  } 
      }
@@ -79,6 +78,7 @@ void report_mflops(const bench_problem *p, double *t, int st)
 void report_time(const bench_problem *p, double *t, int st)
 {
      struct stats s;
+     UNUSED(p);
      mkstat(t, st, &s);
      ovtpvt("(%g %g %g %g)\n", s.min, s.avg, s.max, s.median);
 }
@@ -90,16 +90,22 @@ void report_benchmark(const bench_problem *p, double *t, int st)
      ovtpvt("%.5g %.8g %g\n", mflops(p, s.min), s.min, p->setup_time);
 }
 
-static void sprintf_time(double x, char *buf)
+static void sprintf_time(double x, char *buf, int buflen)
 {
+#ifdef HAVE_SNPRINTF
+#  define MY_SPRINTF(a, b) snprintf(buf, buflen, a, b)
+#else
+#  define MY_SPRINTF(a, b) sprintf(buf, a, b)
+#endif
      if (x < 1.0E-6)
-	  sprintf(buf, "%.2f ns", x * 1.0E9);
+	  MY_SPRINTF("%.2f ns", x * 1.0E9);
      else if (x < 1.0E-3)
-	  sprintf(buf, "%.2f us", x * 1.0E6);
+	  MY_SPRINTF("%.2f us", x * 1.0E6);
      else if (x < 1.0)
-	  sprintf(buf, "%.2f ms", x * 1.0E3);
+	  MY_SPRINTF("%.2f ms", x * 1.0E3);
      else
-	  sprintf(buf, "%.2f s", x);
+	  MY_SPRINTF("%.2f s", x);
+#undef MY_SPRINTF
 }
 
 void report_verbose(const bench_problem *p, double *t, int st)
@@ -107,18 +113,21 @@ void report_verbose(const bench_problem *p, double *t, int st)
      struct stats s;
      char bmin[64], bmax[64], bavg[64], bmedian[64], btmin[64];
      char bsetup[64];
+     int copyp = tensor_sz(p->sz) == 1;
 
      mkstat(t, st, &s);
 
-     sprintf_time(s.min, bmin);
-     sprintf_time(s.max, bmax);
-     sprintf_time(s.avg, bavg);
-     sprintf_time(s.median, bmedian);
-     sprintf_time(time_min, btmin);
-     sprintf_time(p->setup_time, bsetup);
+     sprintf_time(s.min, bmin, 64);
+     sprintf_time(s.max, bmax, 64);
+     sprintf_time(s.avg, bavg, 64);
+     sprintf_time(s.median, bmedian, 64);
+     sprintf_time(time_min, btmin, 64);
+     sprintf_time(p->setup_time, bsetup, 64);
 
-     ovtpvt("Problem: %s, setup: %s, time: %s, ``mflops'': %.5g\n",
-	    p->pstring, bsetup, bmin, mflops(p, s.min));
+     ovtpvt("Problem: %s, setup: %s, time: %s, %s: %.5g\n",
+	    p->pstring, bsetup, bmin, 
+	    copyp ? "fp-move/us" : "``mflops''",
+	    mflops(p, s.min));
 
      if (verbose) {
 	  ovtpvt("Took %d measurements for at least %s each.\n", st, btmin);
