@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2003 Matteo Frigo
- * Copyright (c) 2003 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
  *
  */
 
-/* $Id: verify-dft.c,v 1.13 2003/03/15 20:29:43 stevenj Exp $ */
 
 #include "verify.h"
 
@@ -59,21 +58,24 @@ static void dft_apply(dofft_closure *k_, bench_complex *in, bench_complex *out)
      dofft_dft_closure *k = (dofft_dft_closure *)k_;
      bench_problem *p = k->p;
      bench_tensor *totalsz, *pckdsz;
+     bench_tensor *totalsz_swap, *pckdsz_swap;
      bench_real *ri, *ii, *ro, *io;
-     int n, totalscale;
+     int totalscale;
 
      totalsz = tensor_append(p->vecsz, p->sz);
      pckdsz = verify_pack(totalsz, 2);
-     n = tensor_sz(totalsz);
      ri = (bench_real *) p->in;
      ro = (bench_real *) p->out;
 
+     totalsz_swap = tensor_copy_swapio(totalsz);
+     pckdsz_swap = tensor_copy_swapio(pckdsz);
+
      /* confusion: the stride is the distance between complex elements
 	when using interleaved format, but it is the distance between
 	real elements when using split format */
      if (p->split) {
-	  ii = p->ini ? (bench_real *) p->ini : ri + n;
-	  io = p->outi ? (bench_real *) p->outi : ro + n;
+	  ii = p->ini ? (bench_real *) p->ini : ri + p->iphyssz;
+	  io = p->outi ? (bench_real *) p->outi : ro + p->ophyssz;
 	  totalscale = 1;
      } else {
 	  ii = p->ini ? (bench_real *) p->ini : ri + 1;
@@ -83,12 +85,19 @@ static void dft_apply(dofft_closure *k_, bench_complex *in, bench_complex *out)
 
      cpy(&c_re(in[0]), &c_im(in[0]), pckdsz, 1,
 	    ri, ii, totalsz, totalscale);
+     after_problem_ccopy_from(p, ri, ii);
      doit(1, p);
+     after_problem_ccopy_to(p, ro, io);
+     if (k->k.recopy_input)
+	  cpy(ri, ii, totalsz_swap, totalscale,
+	      &c_re(in[0]), &c_im(in[0]), pckdsz_swap, 1);
      cpy(ro, io, totalsz, totalscale,
 	 &c_re(out[0]), &c_im(out[0]), pckdsz, 1);
 
      tensor_destroy(totalsz);
      tensor_destroy(pckdsz);
+     tensor_destroy(totalsz_swap);
+     tensor_destroy(pckdsz_swap);
 }
 
 void verify_dft(bench_problem *p, int rounds, double tol, errors *e)
@@ -100,6 +109,7 @@ void verify_dft(bench_problem *p, int rounds, double tol, errors *e)
      BENCH_ASSERT(p->kind == PROBLEM_COMPLEX);
 
      k.k.apply = dft_apply;
+     k.k.recopy_input = 0;
      k.p = p;
 
      if (rounds == 0)
@@ -155,6 +165,7 @@ void accuracy_dft(bench_problem *p, int rounds, int impulse_rounds,
      BENCH_ASSERT(p->vecsz->rnk == 0);
 
      k.k.apply = dft_apply;
+     k.k.recopy_input = 0;
      k.p = p;
      n = tensor_sz(p->sz);
 
