@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2003, 2006 Matteo Frigo
- * Copyright (c) 2003, 2006 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -50,11 +50,5 @@ extern hc2hc_solver *(*X(mksolver_hc2hc_hook))(size_t, INT, hc2hc_mkinferior);
 
 void X(regsolver_hc2hc_direct)(planner *plnr, khc2hc codelet, 
 			       const hc2hc_desc *desc);
-void X(regsolver_hc2hc_directbuf)(planner *plnr, khc2hc codelet, 
-				  const hc2hc_desc *desc);
 
 int X(hc2hc_applicable)(const hc2hc_solver *, const problem *, planner *);
-int X(hc2hc_mkcldrn)(rdft_kind kind, INT r, INT m, INT s, 
-		       INT mstart, INT mcount,
-		       R *IO, planner *plnr,
-		       plan **cld0p, plan **cldmp);
