@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2003, 2007-8 Matteo Frigo
- * Copyright (c) 2003, 2007-8 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,11 +18,11 @@
  *
  */
 
-#include "simd.h"
+#include SIMD_HEADER
 
 #define VTW VTW3
 #define TWVL TWVL3
 #define LDW(x) LDA(x, 0, 0)
 
-#define GENUS X(rdft_hc2cbv_genus)
+#define GENUS XSIMD(rdft_hc2cbv_genus)
 extern const hc2c_genus GENUS;
