@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2003 Matteo Frigo
- * Copyright (c) 2003 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,18 +18,21 @@
  *
  */
 
-/* $Id: conf.c,v 1.6 2003/04/08 20:19:39 stevenj Exp $ */
 
 #include "reodft.h"
 
 static const solvtab s =
 {
-     /* SOLVTAB(X(redft00e_r2hc_register)),
-	SOLVTAB(X(rodft00e_r2hc_register)), */
+#if 0 /* 1 to enable "standard" algorithms with substandard accuracy;
+         you must also add them to Makefile.am to compile these files*/
+     SOLVTAB(X(redft00e_r2hc_register)),
+     SOLVTAB(X(rodft00e_r2hc_register)),
+     SOLVTAB(X(reodft11e_r2hc_register)),
+#endif
      SOLVTAB(X(redft00e_r2hc_pad_register)),
      SOLVTAB(X(rodft00e_r2hc_pad_register)),
+     SOLVTAB(X(reodft00e_splitradix_register)),
      SOLVTAB(X(reodft010e_r2hc_register)),
-     /* SOLVTAB(X(reodft11e_r2hc_register)), */
      SOLVTAB(X(reodft11e_radix2_r2hc_register)),
      SOLVTAB(X(reodft11e_r2hc_odd_register)),
 
